==> kotlin-compiler-1.0.2-1-sources.jar: org/jetbrains/kotlin/js/translate/intrinsic/functions/basic/BuiltInFunctionIntrinsic.java <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.js.translate.intrinsic.functions.basic;

import com.google.dart.compiler.backend.js.ast.JsExpression;
import com.google.dart.compiler.backend.js.ast.JsInvocation;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.kotlin.js.translate.context.TranslationContext;
import org.jetbrains.kotlin.js.translate.utils.JsAstUtils;

import java.util.List;

import static org.jetbrains.kotlin.js.translate.utils.JsAstUtils.fqnWithoutSideEffects;

public final class BuiltInFunctionIntrinsic extends FunctionIntrinsic {

    @NotNull
    private final String functionName;

    public BuiltInFunctionIntrinsic(@NotNull String functionName) {
        this.functionName = functionName;
    }

    @NotNull
    @Override
    public JsExpression apply(
            @Nullable JsExpression receiver,
            @NotNull List<JsExpression> arguments,
            @NotNull TranslationContext context
    ) {
        assert receiver != null;
        return new JsInvocation(fqnWithoutSideEffects(functionName, receiver), arguments);
    }
}

==> kotlin-compiler-1.0.7-sources.jar: org/jetbrains/kotlin/js/translate/intrinsic/functions/basic/BuiltInFunctionIntrinsic.java <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.js.translate.intrinsic.functions.basic;

import com.google.dart.compiler.backend.js.ast.JsExpression;
import com.google.dart.compiler.backend.js.ast.JsInvocation;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.kotlin.js.translate.context.TranslationContext;
import org.jetbrains.kotlin.js.translate.utils.JsAstUtils;

import java.util.List;

public final class BuiltInFunctionIntrinsic extends FunctionIntrinsic {

    @NotNull
    private final String functionName;

    public BuiltInFunctionIntrinsic(@NotNull String functionName) {
        this.functionName = functionName;
    }

    @NotNull
    @Override
    public JsExpression apply(
            @Nullable JsExpression receiver,
            @NotNull List<JsExpression> arguments,
            @NotNull TranslationContext context
    ) {
        assert receiver != null;
        return new JsInvocation(JsAstUtils.pureFqn(functionName, receiver), arguments);
    }
}
